/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.wicket;

import java.util.Collections;
import java.util.Map;

import javax.servlet.FilterConfig;
import javax.servlet.ServletException;

import org.apache.wicket.protocol.http.IWebApplicationFactory;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.protocol.http.WicketFilter;
import org.apithefire.servlet.embedded.ServletAndFilterConfig;
import org.apithefire.util.lang.Objects;
import org.apithefire.util.lang.Path;

public class EmbeddedWicketFilter extends WicketFilter {
	
	private final WebApplication webApplication;
	private final Path prefixPath;
	
	public EmbeddedWicketFilter(WebApplication webApplication, Path prefixPath) {
		this.webApplication = Objects.nonNull(webApplication);
		this.prefixPath = Objects.nonNull(prefixPath);
	}

	public WebApplication getWebApplication() {
		return webApplication;
	}

	public Path getPrefixPath() {
		return prefixPath;
	}

	@Override
	public void init(FilterConfig config) throws ServletException {
		String prefixPathPattern = getPrefixPathPattern();
		Map<String, String> initParamMap = Collections.singletonMap(
				WicketFilter.FILTER_MAPPING_PARAM, prefixPathPattern);
		
		super.init(ServletAndFilterConfig.overrideInitParameters(config,
				initParamMap));
	}
	
	private String getPrefixPathPattern() {
		return new Path("").concat(prefixPath.trim()).concat(
				new Path("*")).toString();
	}
	
	@Override
	protected IWebApplicationFactory getApplicationFactory() {
		return new IWebApplicationFactory() {
			public WebApplication createApplication(
					org.apache.wicket.protocol.http.WicketFilter filter) {
				return webApplication;
			}
		};
	}

}
